
# Slot: subclass_of


rdfs:subClassOf to be emitted in OWL generation

URI: [linkml:subclass_of](https://w3id.org/linkml/subclass_of)


## Domain and Range

class_definition &#8594;  <sub>0..1</sub> uriorcurie

## Parents


## Children


## Used by

 * class_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdfs:subClassOf |

